==> deepin-camera_6.0.11.tar.xz: BUILD/src/translations/deepin-camera_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>L&apos;enregistrement vidéo est en cours. Fermer la fenêtre ?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Ouvrir dossier</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Ouvrir dossier</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Vous n&apos;êtes pas autorisé à modifier ce dossier</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Dossier invalide</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Ouvrir dossier</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Simple</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Emplacement du fichier</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Prendre</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Mode rafale</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Délai du retardateur</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Sortie</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Format de sortie</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pcs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pcs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Caméra</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Camera est un utilitaire de capture d&apos;images et de vidéos utilisant votre caméra intégrée ou votre webcam.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Fichier non sauvegardé</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Enregistrer dans :</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Photo :</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Vidéo :</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Paramètres de résolution</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Résolution : </translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Photos :</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Vidéos :</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Effets sonores</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Caméra</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Arrêter l&apos;enregistrement</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Afficher les raccourcis</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Arrêter de prendre des photos</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menu contextuel</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Prendre une photo</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Enregistrer une vidéo</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Arrêter de prendre des photos</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Aucune webcam trouvée</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>La webcam est en cours d&apos;utilisation</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Arrêter l&apos;enregistrement</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.20.tar.xz: BUILD/src/translations/deepin-camera_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>L&apos;enregistrement vidéo est en cours. Fermer la fenêtre ?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Ouvrir dossier</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Photo</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vidéo</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Changer de caméra</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Ouvrir dossier</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Vous n&apos;êtes pas autorisé à modifier ce dossier</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Dossier invalide</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Ouvrir dossier</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Simple</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Emplacement du fichier</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Prendre</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Mode rafale</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Délai du retardateur</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Sortie</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Format de sortie</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pcs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pcs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Caméra</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Caméra est un utilitaire de capture d&apos;images et de vidéos utilisant votre caméra intégrée ou votre webcam.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Fichier non sauvegardé</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Enregistrer dans :</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Photo :</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Vidéo :</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Paramètres de résolution</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Résolution : </translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Photos :</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Vidéos :</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Effets sonores</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Mode miroir</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Lignes de grille</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>lignes 1x1</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>lignes 2x2</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Résolution maximale :</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Caméra</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Arrêter l&apos;enregistrement</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Afficher les raccourcis</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Arrêter de prendre des photos</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menu contextuel</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Prendre une photo</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Enregistrer une vidéo</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Arrêter de prendre des photos</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Vif</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Chaud</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Froid</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Rétro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>N&amp;B</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>On</source>
        <translation>On</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Off</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Retarder la capture</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtres</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Exposition</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Aucune webcam trouvée</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>La webcam est en cours d&apos;utilisation</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Arrêter l&apos;enregistrement</translation>
    </message>
</context>
</TS>
